# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.portfolio.credit import Credit

__all__ = ["CreditResource", "AsyncCreditResource"]


class CreditResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> CreditResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return CreditResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CreditResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return CreditResourceWithStreamingResponse(self)

    def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Credit:
        """Get credit data"""
        return self._get(
            "/portfolio/credit",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Credit,
        )

    def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Credit:
        """Get credit data"""
        return self._get(
            "/portfolio/credit",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Credit,
        )


class AsyncCreditResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncCreditResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCreditResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCreditResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return AsyncCreditResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Credit:
        """Get credit data"""
        return await self._get(
            "/portfolio/credit",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Credit,
        )

    async def get(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Credit:
        """Get credit data"""
        return await self._get(
            "/portfolio/credit",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Credit,
        )


class CreditResourceWithRawResponse:
    def __init__(self, credit: CreditResource) -> None:
        self._credit = credit

        self.retrieve = to_raw_response_wrapper(
            credit.retrieve,
        )
        self.get = to_raw_response_wrapper(
            credit.get,
        )


class AsyncCreditResourceWithRawResponse:
    def __init__(self, credit: AsyncCreditResource) -> None:
        self._credit = credit

        self.retrieve = async_to_raw_response_wrapper(
            credit.retrieve,
        )
        self.get = async_to_raw_response_wrapper(
            credit.get,
        )


class CreditResourceWithStreamingResponse:
    def __init__(self, credit: CreditResource) -> None:
        self._credit = credit

        self.retrieve = to_streamed_response_wrapper(
            credit.retrieve,
        )
        self.get = to_streamed_response_wrapper(
            credit.get,
        )


class AsyncCreditResourceWithStreamingResponse:
    def __init__(self, credit: AsyncCreditResource) -> None:
        self._credit = credit

        self.retrieve = async_to_streamed_response_wrapper(
            credit.retrieve,
        )
        self.get = async_to_streamed_response_wrapper(
            credit.get,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .credit import (
    CreditResource,
    AsyncCreditResource,
    CreditResourceWithRawResponse,
    AsyncCreditResourceWithRawResponse,
    CreditResourceWithStreamingResponse,
    AsyncCreditResourceWithStreamingResponse,
)
from .balance import (
    BalanceResource,
    AsyncBalanceResource,
    BalanceResourceWithRawResponse,
    AsyncBalanceResourceWithRawResponse,
    BalanceResourceWithStreamingResponse,
    AsyncBalanceResourceWithStreamingResponse,
)
from .portfolio import (
    PortfolioResource,
    AsyncPortfolioResource,
    PortfolioResourceWithRawResponse,
    AsyncPortfolioResourceWithRawResponse,
    PortfolioResourceWithStreamingResponse,
    AsyncPortfolioResourceWithStreamingResponse,
)
from .open_position import (
    OpenPositionResource,
    AsyncOpenPositionResource,
    OpenPositionResourceWithRawResponse,
    AsyncOpenPositionResourceWithRawResponse,
    OpenPositionResourceWithStreamingResponse,
    AsyncOpenPositionResourceWithStreamingResponse,
)

__all__ = [
    "BalanceResource",
    "AsyncBalanceResource",
    "BalanceResourceWithRawResponse",
    "AsyncBalanceResourceWithRawResponse",
    "BalanceResourceWithStreamingResponse",
    "AsyncBalanceResourceWithStreamingResponse",
    "OpenPositionResource",
    "AsyncOpenPositionResource",
    "OpenPositionResourceWithRawResponse",
    "AsyncOpenPositionResourceWithRawResponse",
    "OpenPositionResourceWithStreamingResponse",
    "AsyncOpenPositionResourceWithStreamingResponse",
    "CreditResource",
    "AsyncCreditResource",
    "CreditResourceWithRawResponse",
    "AsyncCreditResourceWithRawResponse",
    "CreditResourceWithStreamingResponse",
    "AsyncCreditResourceWithStreamingResponse",
    "PortfolioResource",
    "AsyncPortfolioResource",
    "PortfolioResourceWithRawResponse",
    "AsyncPortfolioResourceWithRawResponse",
    "PortfolioResourceWithStreamingResponse",
    "AsyncPortfolioResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Order"]


class Order(BaseModel):
    order_id: Optional[str] = FieldInfo(alias="orderId", default=None)

    price: Optional[str] = None

    quantity: Optional[str] = None

    side: Optional[Literal["buy", "sell"]] = None

    symbol: Optional[str] = None

    type: Optional[Literal["market", "limit"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .kline import (
    KlineResource,
    AsyncKlineResource,
    KlineResourceWithRawResponse,
    AsyncKlineResourceWithRawResponse,
    KlineResourceWithStreamingResponse,
    AsyncKlineResourceWithStreamingResponse,
)
from .ticker import (
    TickerResource,
    AsyncTickerResource,
    TickerResourceWithRawResponse,
    AsyncTickerResourceWithRawResponse,
    TickerResourceWithStreamingResponse,
    AsyncTickerResourceWithStreamingResponse,
)
from ..._compat import cached_property
from .instrument import (
    InstrumentResource,
    AsyncInstrumentResource,
    InstrumentResourceWithRawResponse,
    AsyncInstrumentResourceWithRawResponse,
    InstrumentResourceWithStreamingResponse,
    AsyncInstrumentResourceWithStreamingResponse,
)
from .order_book import (
    OrderBookResource,
    AsyncOrderBookResource,
    OrderBookResourceWithRawResponse,
    AsyncOrderBookResourceWithRawResponse,
    OrderBookResourceWithStreamingResponse,
    AsyncOrderBookResourceWithStreamingResponse,
)
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["MarketResource", "AsyncMarketResource"]


class MarketResource(SyncAPIResource):
    @cached_property
    def instrument(self) -> InstrumentResource:
        return InstrumentResource(self._client)

    @cached_property
    def order_book(self) -> OrderBookResource:
        return OrderBookResource(self._client)

    @cached_property
    def ticker(self) -> TickerResource:
        return TickerResource(self._client)

    @cached_property
    def kline(self) -> KlineResource:
        return KlineResource(self._client)

    @cached_property
    def with_raw_response(self) -> MarketResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return MarketResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MarketResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return MarketResourceWithStreamingResponse(self)


class AsyncMarketResource(AsyncAPIResource):
    @cached_property
    def instrument(self) -> AsyncInstrumentResource:
        return AsyncInstrumentResource(self._client)

    @cached_property
    def order_book(self) -> AsyncOrderBookResource:
        return AsyncOrderBookResource(self._client)

    @cached_property
    def ticker(self) -> AsyncTickerResource:
        return AsyncTickerResource(self._client)

    @cached_property
    def kline(self) -> AsyncKlineResource:
        return AsyncKlineResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMarketResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMarketResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMarketResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return AsyncMarketResourceWithStreamingResponse(self)


class MarketResourceWithRawResponse:
    def __init__(self, market: MarketResource) -> None:
        self._market = market

    @cached_property
    def instrument(self) -> InstrumentResourceWithRawResponse:
        return InstrumentResourceWithRawResponse(self._market.instrument)

    @cached_property
    def order_book(self) -> OrderBookResourceWithRawResponse:
        return OrderBookResourceWithRawResponse(self._market.order_book)

    @cached_property
    def ticker(self) -> TickerResourceWithRawResponse:
        return TickerResourceWithRawResponse(self._market.ticker)

    @cached_property
    def kline(self) -> KlineResourceWithRawResponse:
        return KlineResourceWithRawResponse(self._market.kline)


class AsyncMarketResourceWithRawResponse:
    def __init__(self, market: AsyncMarketResource) -> None:
        self._market = market

    @cached_property
    def instrument(self) -> AsyncInstrumentResourceWithRawResponse:
        return AsyncInstrumentResourceWithRawResponse(self._market.instrument)

    @cached_property
    def order_book(self) -> AsyncOrderBookResourceWithRawResponse:
        return AsyncOrderBookResourceWithRawResponse(self._market.order_book)

    @cached_property
    def ticker(self) -> AsyncTickerResourceWithRawResponse:
        return AsyncTickerResourceWithRawResponse(self._market.ticker)

    @cached_property
    def kline(self) -> AsyncKlineResourceWithRawResponse:
        return AsyncKlineResourceWithRawResponse(self._market.kline)


class MarketResourceWithStreamingResponse:
    def __init__(self, market: MarketResource) -> None:
        self._market = market

    @cached_property
    def instrument(self) -> InstrumentResourceWithStreamingResponse:
        return InstrumentResourceWithStreamingResponse(self._market.instrument)

    @cached_property
    def order_book(self) -> OrderBookResourceWithStreamingResponse:
        return OrderBookResourceWithStreamingResponse(self._market.order_book)

    @cached_property
    def ticker(self) -> TickerResourceWithStreamingResponse:
        return TickerResourceWithStreamingResponse(self._market.ticker)

    @cached_property
    def kline(self) -> KlineResourceWithStreamingResponse:
        return KlineResourceWithStreamingResponse(self._market.kline)


class AsyncMarketResourceWithStreamingResponse:
    def __init__(self, market: AsyncMarketResource) -> None:
        self._market = market

    @cached_property
    def instrument(self) -> AsyncInstrumentResourceWithStreamingResponse:
        return AsyncInstrumentResourceWithStreamingResponse(self._market.instrument)

    @cached_property
    def order_book(self) -> AsyncOrderBookResourceWithStreamingResponse:
        return AsyncOrderBookResourceWithStreamingResponse(self._market.order_book)

    @cached_property
    def ticker(self) -> AsyncTickerResourceWithStreamingResponse:
        return AsyncTickerResourceWithStreamingResponse(self._market.ticker)

    @cached_property
    def kline(self) -> AsyncKlineResourceWithStreamingResponse:
        return AsyncKlineResourceWithStreamingResponse(self._market.kline)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["Balance"]


class Balance(BaseModel):
    asset: Optional[str] = None

    free: Optional[str] = None

    locked: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["Kline"]


class Kline(BaseModel):
    close: Optional[str] = None

    high: Optional[str] = None

    low: Optional[str] = None

    open: Optional[str] = None

    open_time: Optional[datetime] = FieldInfo(alias="openTime", default=None)

    volume: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .userdata import (
    UserdataResource,
    AsyncUserdataResource,
    UserdataResourceWithRawResponse,
    AsyncUserdataResourceWithRawResponse,
    UserdataResourceWithStreamingResponse,
    AsyncUserdataResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["AccountResource", "AsyncAccountResource"]


class AccountResource(SyncAPIResource):
    @cached_property
    def userdata(self) -> UserdataResource:
        return UserdataResource(self._client)

    @cached_property
    def with_raw_response(self) -> AccountResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AccountResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AccountResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return AccountResourceWithStreamingResponse(self)


class AsyncAccountResource(AsyncAPIResource):
    @cached_property
    def userdata(self) -> AsyncUserdataResource:
        return AsyncUserdataResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAccountResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAccountResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAccountResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/SigmaEf5ect/sigma-sdk-python#with_streaming_response
        """
        return AsyncAccountResourceWithStreamingResponse(self)


class AccountResourceWithRawResponse:
    def __init__(self, account: AccountResource) -> None:
        self._account = account

    @cached_property
    def userdata(self) -> UserdataResourceWithRawResponse:
        return UserdataResourceWithRawResponse(self._account.userdata)


class AsyncAccountResourceWithRawResponse:
    def __init__(self, account: AsyncAccountResource) -> None:
        self._account = account

    @cached_property
    def userdata(self) -> AsyncUserdataResourceWithRawResponse:
        return AsyncUserdataResourceWithRawResponse(self._account.userdata)


class AccountResourceWithStreamingResponse:
    def __init__(self, account: AccountResource) -> None:
        self._account = account

    @cached_property
    def userdata(self) -> UserdataResourceWithStreamingResponse:
        return UserdataResourceWithStreamingResponse(self._account.userdata)


class AsyncAccountResourceWithStreamingResponse:
    def __init__(self, account: AsyncAccountResource) -> None:
        self._account = account

    @cached_property
    def userdata(self) -> AsyncUserdataResourceWithStreamingResponse:
        return AsyncUserdataResourceWithStreamingResponse(self._account.userdata)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["Ticker"]


class Ticker(BaseModel):
    price: Optional[str] = None

    symbol: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TradingSubmitParams"]


class TradingSubmitParams(TypedDict, total=False):
    order_id: Annotated[str, PropertyInfo(alias="orderId")]

    price: str

    quantity: str

    side: Literal["buy", "sell"]

    symbol: str

    type: Literal["market", "limit"]
